import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorSnackBar extends SnackBar {
  SeniorSnackBar({
    Key? key,
    required String message,
    IconData? icon,
    Color? backgroundColor,
    Color? fontColor,
    SnackBarAction? action,
    Duration duration = const Duration(seconds: 3),
  }) : super(
    key: key,
    content: Row(
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        Visibility(
          visible: icon != null,
          child: Icon(
            icon,
            color: fontColor,
            size: SeniorTypographyIconSize.text,
          ),
        ),
        SizedBox(width: 8.0),
        Text(
          message,
          style: SeniorTypography.text(
            color: fontColor,
          ),
        ),
      ],
    ),
    action: action,
    duration: duration,
    behavior: SnackBarBehavior.floating,
    backgroundColor: backgroundColor,
  );

  factory SeniorSnackBar.info({
    Key? key,
    required String message,
    SnackBarAction? action,
    Duration duration,
  }) = _SeniorSnackBarInfo;

  factory SeniorSnackBar.success({
    Key? key,
    required String message,
    SnackBarAction? action,
    Duration duration,
  }) = _SeniorSnackBarSuccess; 

  factory SeniorSnackBar.warning({
    Key? key,
    required String message,
    SnackBarAction? action,
    Duration duration,
  }) = _SeniorSnackBarWarning;

  factory SeniorSnackBar.error({
    Key? key,
    required String message,
    SnackBarAction? action,
    Duration duration,
  }) = _SeniorSnackBarError; 
}

  class _SeniorSnackBarInfo extends SeniorSnackBar {
  _SeniorSnackBarInfo({
    Key? key,
    required String message,
    SnackBarAction? action,
    Duration duration = const Duration(seconds: 3),
  }) : super(
    key: key,
    message: message,
    action: action,
    duration: duration,
    backgroundColor: SeniorColors.manchesterColorBlue300,
    icon: FontAwesomeIcons.info,
    fontColor: SeniorColors.pureBlack,
  );  
}

class _SeniorSnackBarSuccess extends SeniorSnackBar {
  _SeniorSnackBarSuccess({
    Key? key,
    required String message,
    SnackBarAction? action,
    Duration duration = const Duration(seconds: 3),
  }) : super(
    key: key,
    message: message,
    action: action,
    duration: duration,
    backgroundColor: SeniorColors.manchesterColorGreen300,
    icon: FontAwesomeIcons.check,
    fontColor: SeniorColors.pureBlack,
  );
}

class _SeniorSnackBarWarning extends SeniorSnackBar {
  _SeniorSnackBarWarning({
    Key? key,
    required String message,
    SnackBarAction? action,
    Duration duration = const Duration(seconds: 3),
  }) : super(
    key: key,
    message: message,
    action: action,
    duration: duration,
    backgroundColor: SeniorColors.manchesterColorYellow300,
    icon: FontAwesomeIcons.exclamation,
    fontColor: SeniorColors.pureBlack,
  );
}

class _SeniorSnackBarError extends SeniorSnackBar {
  _SeniorSnackBarError({
    Key? key,
    required String message,
    SnackBarAction? action,
    Duration duration = const Duration(seconds: 3),
  }) : super(
    key: key,
    message: message,
    action: action,
    duration: duration,
    backgroundColor: SeniorColors.manchesterColorRed300,
    icon: FontAwesomeIcons.times,
    fontColor: SeniorColors.pureBlack,
  );
}